PALM-meteo: palmmeteo_stdplugins.wrf Namespace Reference

PALM-meteo

Classes | Functions | Variables
palmmeteo_stdplugins.wrf Namespace Reference

## Classes
class | WRFPlugin
class | WRFRadPlugin

## Functions
def | lpad (var)
def | log_dstat_on (desc, delta)
def | log_dstat_off (desc, delta)
def | wrfout_dt (fin)

## Variables
| barom_pres = PalmPhysics.barom_lapse0_pres
| barom_gp = PalmPhysics.barom_lapse0_gp
| g = PalmPhysics.g
string | dtformat_wrf = '%Y-%m-%d_%H:%M:%S'

## Function Documentation

## ◆ log_dstat_off()

def palmmeteo_stdplugins.wrf.log_dstat_off | ( |  | desc,
|  |  | delta
| ) |  |

    Do nothing (log disabled)

## ◆ log_dstat_on()

def palmmeteo_stdplugins.wrf.log_dstat_on | ( |  | desc,
|  |  | delta
| ) |  |

    Calculate and log delta statistics if enabled.

## ◆ lpad()

def palmmeteo_stdplugins.wrf.lpad | ( |  | var | ) |

    Pad variable in first dimension by repeating lowest layer twice

## ◆ wrfout_dt()

def palmmeteo_stdplugins.wrf.wrfout_dt | ( |  | fin | ) |

    Return cycle time and time for the specific wrfout

## Variable Documentation

## ◆ barom_gp

palmmeteo_stdplugins.wrf.barom_gp = PalmPhysics.barom_lapse0_gp

## ◆ barom_pres

palmmeteo_stdplugins.wrf.barom_pres = PalmPhysics.barom_lapse0_pres

## ◆ dtformat_wrf

string palmmeteo_stdplugins.wrf.dtformat_wrf = '%Y-%m-%d_%H:%M:%S'

## ◆ g

palmmeteo_stdplugins.wrf.g = PalmPhysics.g